==> 1.4.5.tar.gz: lib/XStylesBase.dart <==
import 'package:flutter/material.dart';

class XStyles {
  /// fontSize 24
  static TextStyle xStyTextForLargeTitle([Color? textColor]) {
    return TextStyle(fontSize: 24, color: textColor ?? Colors.white);
  }

  /// fontSize 22
  static TextStyle xStyTextForTitle([Color? textColor]) {
    return TextStyle(fontSize: 22, color: textColor ?? Colors.white);
  }

  /// fontSize 20
  static TextStyle xStyTextForLabel([Color? textColor]) {
    return TextStyle(fontSize: 20, color: textColor ?? Colors.white);
  }

  /// fontSize 18
  static TextStyle xStyTextForTextBase([Color? textColor]) {
    return TextStyle(fontSize: 18, color: textColor ?? Colors.white);
  }

  /// fontSize 16
  static TextStyle xStyTextForDescr([Color? textColor]) {
    return TextStyle(fontSize: 16, color: textColor ?? Colors.white);
  }

  static TextStyle xStyleText({Color? colorText, double? fontSize, bool? activeBold = false, double? letterSpacing}) {
    return TextStyle(color: colorText ?? XColors.xcolor_ForegroundLight, fontSize: fontSize ?? 18, fontWeight: activeBold == false ? null : FontWeight.bold, letterSpacing: letterSpacing ?? 0);
  }
}

///////////  C O L O R S   B A S E  ///////////

class XColors {
  static final Color? primaryLight = Colors.white;
  static final Color? primaryDark = Colors.black;

//// THEME LIGHT ////
  static get xcolor_BackgroundLight => primaryLight;
  static get xcolor_ForegroundLight => primaryLight;

//// THEME DARK ////
  static get xcolor_BackgroundDark => primaryDark;
  static get xcolor_ForegroundDark => primaryDark;

//// THEME COLOR GENERAL ////
  static get xcolor_Done => Colors.greenAccent;
  static get xcolor_Undo => Colors.redAccent;
  static get xcolor_Warning => Colors.yellow;
  static get xcolor_BackGroungTitleDark => Colors.grey[800];
}

///////////  I C O N S   B A S E  ///////////

class XIcons {
  static get xicon_Done => Icons.done;
  static get xicon_Warning => Icons.warning;
  static get xicon_Delete => Icons.delete;
  static get xicon_Undo => Icons.undo;
  static get xicon_Refresh => Icons.refresh;
}

class XDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static boxBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static circularBoxBorderAll(Color? color) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static boxEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static box_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static gradientBox_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static circularBox_Gradient_GreenAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static gradientBox_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static circularBox_Gradient_GreenLightAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// ORANGE

  static box_Gradient_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static circularBox_Gradient_OrangeAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// YELLOW

  static gradientBox_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static circularBox_Gradient_Yellow({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// TEAL

  static gradientBox_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static circularBox_Gradient_Teal({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// GREY

  static gradientBox_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static circularBox_Gradient_Grey({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// RED

  static gradientBox_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static circularBox_Gradient_RedAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BLUE

  static gradientBox_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static circularBox_Gradient_Blue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  /// PURPLE

  static gradientBox_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static circularBox_Gradient_Purple({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }
}

==> 1.5.0.tar.gz: lib/XStylesBase.dart <==
import 'package:flutter/material.dart';

class XStyles {
  /// fontSize 24
  static TextStyle xStyTextForLargeTitle([Color? textColor]) {
    return TextStyle(fontSize: 24, color: textColor ?? Colors.white);
  }

  /// fontSize 22
  static TextStyle xStyTextForTitle([Color? textColor]) {
    return TextStyle(fontSize: 22, color: textColor ?? Colors.white);
  }

  /// fontSize 20
  static TextStyle xStyTextForLabel([Color? textColor]) {
    return TextStyle(fontSize: 20, color: textColor ?? Colors.white);
  }

  /// fontSize 18
  static TextStyle xStyTextForTextBase([Color? textColor]) {
    return TextStyle(fontSize: 18, color: textColor ?? Colors.white);
  }

  /// fontSize 17
  static TextStyle xStyTextForSubLabel([Color? textColor]) {
    return TextStyle(fontSize: 17, color: textColor ?? Colors.white);
  }

  /// fontSize 16
  static TextStyle xStyTextForDescr([Color? textColor]) {
    return TextStyle(fontSize: 16, color: textColor ?? Colors.white);
  }

  /// fontSize 15
  static TextStyle xStyTextForSubDescr([Color? textColor]) {
    return TextStyle(fontSize: 15, color: textColor ?? Colors.white);
  }

  static TextStyle xStyleText({Color? colorText, double? fontSize, bool? activeBold = false, double? letterSpacing}) {
    return TextStyle(color: colorText ?? XColors.xcolor_ForegroundLight, fontSize: fontSize ?? 18, fontWeight: activeBold == false ? null : FontWeight.bold, letterSpacing: letterSpacing ?? 0);
  }
}

///////////  C O L O R S   B A S E  ///////////

class XColors {
  static final Color? primaryLight = Colors.white;
  static final Color? primaryDark = Colors.black;

//// THEME LIGHT ////
  static get xcolor_BackgroundLight => primaryLight;
  static get xcolor_ForegroundLight => primaryLight;

//// THEME DARK ////
  static get xcolor_BackgroundDark => primaryDark;
  static get xcolor_ForegroundDark => primaryDark;

//// THEME COLOR GENERAL ////
  static get xcolor_Done => Colors.greenAccent;
  static get xcolor_Undo => Colors.redAccent;
  static get xcolor_Warning => Colors.yellow;
  static get xcolor_BackGroungTitleDark => Colors.grey[800];
}

///////////  I C O N S   B A S E  ///////////

class XIcons {
  static get xicon_Done => Icons.done;
  static get xicon_Warning => Icons.warning;
  static get xicon_Delete => Icons.delete;
  static get xicon_Undo => Icons.undo;
  static get xicon_Refresh => Icons.refresh;
}

class XDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static boxBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static circularBox({Color? color, double? borderRadius}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static boxEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static box_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static gradientBox_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static circularBox_Gradient_GreenAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static gradientBox_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static circularBox_Gradient_GreenLightAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static circularBox_Gradient_GreenLight({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.green[300]!, Colors.green[400]!, Colors.green[500]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// ORANGE

  static gradientBox_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static circularBox_Gradient_OrangeAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// YELLOW

  static gradientBox_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static circularBox_Gradient_Yellow({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// TEAL

  static gradientBox_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static circularBox_Gradient_Teal({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// GREY

  static gradientBox_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static circularBox_Gradient_Grey({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// RED

  static gradientBox_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static circularBox_Gradient_RedAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BLUE

  static gradientBox_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static circularBox_Gradient_Blue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  /// PURPLE

  static gradientBox_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static circularBox_Gradient_Purple({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }
}
